==> secretsmanager-1.60.0-sources.jar: software/amazon/awscdk/services/secretsmanager/SecretRotationApplicationOptions.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Options for a SecretRotationApplication.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.439Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.SecretRotationApplicationOptions")
@software.amazon.jsii.Jsii.Proxy(SecretRotationApplicationOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SecretRotationApplicationOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether the rotation application uses the mutli user scheme.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIsMultiUser() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SecretRotationApplicationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SecretRotationApplicationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SecretRotationApplicationOptions> {
        private java.lang.Boolean isMultiUser;

        /**
         * Sets the value of {@link SecretRotationApplicationOptions#getIsMultiUser}
         * @param isMultiUser Whether the rotation application uses the mutli user scheme.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder isMultiUser(java.lang.Boolean isMultiUser) {
            this.isMultiUser = isMultiUser;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SecretRotationApplicationOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SecretRotationApplicationOptions build() {
            return new Jsii$Proxy(isMultiUser);
        }
    }

    /**
     * An implementation for {@link SecretRotationApplicationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SecretRotationApplicationOptions {
        private final java.lang.Boolean isMultiUser;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.isMultiUser = this.jsiiGet("isMultiUser", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean isMultiUser) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.isMultiUser = isMultiUser;
        }

        @Override
        public java.lang.Boolean getIsMultiUser() {
            return this.isMultiUser;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIsMultiUser() != null) {
                data.set("isMultiUser", om.valueToTree(this.getIsMultiUser()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.SecretRotationApplicationOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SecretRotationApplicationOptions.Jsii$Proxy that = (SecretRotationApplicationOptions.Jsii$Proxy) o;

            return this.isMultiUser != null ? this.isMultiUser.equals(that.isMultiUser) : that.isMultiUser == null;
        }

        @Override
        public int hashCode() {
            int result = this.isMultiUser != null ? this.isMultiUser.hashCode() : 0;
            return result;
        }
    }
}

==> secretsmanager-1.100.0-sources.jar: software/amazon/awscdk/services/secretsmanager/SecretRotationApplicationOptions.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Options for a SecretRotationApplication.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:15.668Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.SecretRotationApplicationOptions")
@software.amazon.jsii.Jsii.Proxy(SecretRotationApplicationOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SecretRotationApplicationOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether the rotation application uses the mutli user scheme.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIsMultiUser() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SecretRotationApplicationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SecretRotationApplicationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SecretRotationApplicationOptions> {
        private java.lang.Boolean isMultiUser;

        /**
         * Sets the value of {@link SecretRotationApplicationOptions#getIsMultiUser}
         * @param isMultiUser Whether the rotation application uses the mutli user scheme.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder isMultiUser(java.lang.Boolean isMultiUser) {
            this.isMultiUser = isMultiUser;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SecretRotationApplicationOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SecretRotationApplicationOptions build() {
            return new Jsii$Proxy(isMultiUser);
        }
    }

    /**
     * An implementation for {@link SecretRotationApplicationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SecretRotationApplicationOptions {
        private final java.lang.Boolean isMultiUser;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.isMultiUser = software.amazon.jsii.Kernel.get(this, "isMultiUser", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Boolean isMultiUser) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.isMultiUser = isMultiUser;
        }

        @Override
        public final java.lang.Boolean getIsMultiUser() {
            return this.isMultiUser;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIsMultiUser() != null) {
                data.set("isMultiUser", om.valueToTree(this.getIsMultiUser()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.SecretRotationApplicationOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SecretRotationApplicationOptions.Jsii$Proxy that = (SecretRotationApplicationOptions.Jsii$Proxy) o;

            return this.isMultiUser != null ? this.isMultiUser.equals(that.isMultiUser) : that.isMultiUser == null;
        }

        @Override
        public final int hashCode() {
            int result = this.isMultiUser != null ? this.isMultiUser.hashCode() : 0;
            return result;
        }
    }
}
